package tetris.model;

import tetris.Tetris;
import tetris.gui.ActionEvent;
import tetris.gui.Block;
import tetris.gui.GUI;

/**
 * The class Game implements the Tetris game.
 *
 * @author Stephan Fischli
 * @version 2.1
 */
public class Game {

	/**
	 * The graphical user interface.
	 */
	private final GUI gui;

	/**
	 * The block of the game.
	 */
	private Block block;

	/**
	 * Constructs a game with a graphical user interface.
	 *
	 * @param gui the graphical user interface
	 */
	public Game(GUI gui) {
		this.gui = gui;
	}

	/**
	 * Starts the game by creating a block and waiting for action events.
	 */
	public void start() {
		createBlock();
		while (true) {
			ActionEvent event = gui.waitEvent();
			handleEvent(event);
		}
	}

	/**
	 * Creates a block at the top of the field.
	 */
	private void createBlock() {
		block = new Block((Tetris.WIDTH - 1) / 2, Tetris.HEIGHT - 1, 1);
		updateGUI();
	}

	/**
	 * Handles an action event by moving the block accordingly.
	 *
	 * @param event the event to handle
	 */
	private void handleEvent(ActionEvent event) {
		switch (event) {
			case SHIFT_DOWN -> block.y--;
			case SHIFT_LEFT -> block.x--;
			case SHIFT_RIGHT -> block.x++;
		}
		updateGUI();
	}

	/**
	 * Updates the graphical user interface according to the current state of the game.
	 */
	private void updateGUI() {
		gui.clear();
		gui.drawBlock(block);
	}
}
